@@ -23,6 +23,9 @@
 #' In the unlikely event that there is a problem with this function, an nflfastR
 #' internal decoder can be used with the option `fast = FALSE`.
 #'
+#' The 2022 play by play data introduced new player IDs that can't be decoded
+#' with gsisdecoder. In that case, IDs are joined through [nflreadr::load_players].
+#'
 #' @return The input data frame of the parameter `pbp` with decoded player IDs.
 #' @export
 #' @examples
@@ -40,6 +43,12 @@
 #' ))
 #' }
 decode_player_ids <- function(pbp, ..., fast = TRUE) {
+  if ("game_id" %in% names(pbp)){
+    season <- substr(pbp$game_id, 1, 4) %>% unique() %>% as.numeric()
+  }  else {
+    season <- 0
+  }
+
   if (isFALSE(fast)) {
     if (nrow(pbp) > 1000 && is_sequential()) {
       cli::cli_alert_info(c(
@@ -58,6 +67,32 @@ decode_player_ids <- function(pbp, ..., fast = TRUE) {
         ),
         decode_ids
       )
+  } else if (any(season >= 9999)) {
+    # this isn't necessary now, but keeping this here in case the ID system changes
+
+    # need newer version of nflreadr to use load_players
+    rlang::check_installed("nflreadr (>= 1.3.0)", "to decode 2022ff player IDs.")
+
+    players <- nflreadr::load_players()
+
+    id_vector <- players$gsis_id
+    names(id_vector) <- players$smart_id
+
+    ret <- pbp %>%
+      dplyr::mutate_at(
+        dplyr::vars(
+          tidyselect::any_of(c("passer_id", "rusher_id", "receiver_id", "id", "fantasy_id")),
+          tidyselect::ends_with("player_id")
+        ),
+        function(id, id_vec = id_vector){
+          chars <- nchar(id)
+          dplyr::case_when(
+            is.na(chars) ~ NA_character_,
+            chars == 36 ~ id_vec[id],
+            TRUE ~ id
+          )
+        }
+      )
   } else if (isTRUE(fast)) {
     if (!is_installed("gsisdecoder")) {
       cli::cli_abort("Package {.val gsisdecoder} required for fast decoding. Please install it with {.code install.packages(\"gsisdecoder\")}.")
